Class: Invoicetronic_Sdk::Company

Inherits:
ApiModelBase show all
Defined in:
lib/invoicetronic_sdk/models/company.rb

Overview

A company model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Company

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/invoicetronic_sdk/models/company.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Invoicetronic_Sdk::Company` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Invoicetronic_Sdk::Company`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'vat')
    self.vat = attributes[:'vat']
  else
    self.vat = nil
  end

  if attributes.key?(:'fiscal_code')
    self.fiscal_code = attributes[:'fiscal_code']
  else
    self.fiscal_code = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end
end

Instance Attribute Details

#createdObject

Creation date. It is set automatically.



23
24
25
# File 'lib/invoicetronic_sdk/models/company.rb', line 23

def created
  @created
end

#fiscal_codeObject

Fiscal code. In most cases it’s the same as the vat number.



35
36
37
# File 'lib/invoicetronic_sdk/models/company.rb', line 35

def fiscal_code
  @fiscal_code
end

#idObject

Unique identifier. For POST requests, leave it at ‘0` — the server will assign one automatically. For PUT requests, set it to the id of the record you want to update.



20
21
22
# File 'lib/invoicetronic_sdk/models/company.rb', line 20

def id
  @id
end

#nameObject

Name



38
39
40
# File 'lib/invoicetronic_sdk/models/company.rb', line 38

def name
  @name
end

#user_idObject

User id. It is set automatically based on the authenticated user.



29
30
31
# File 'lib/invoicetronic_sdk/models/company.rb', line 29

def user_id
  @user_id
end

#vatObject

Vat number. Must include the country code.



32
33
34
# File 'lib/invoicetronic_sdk/models/company.rb', line 32

def vat
  @vat
end

#versionObject

Row version, for optimistic concurrency. It is set automatically.



26
27
28
# File 'lib/invoicetronic_sdk/models/company.rb', line 26

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/invoicetronic_sdk/models/company.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/invoicetronic_sdk/models/company.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/invoicetronic_sdk/models/company.rb', line 41

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'version' => :'version',
    :'user_id' => :'user_id',
    :'vat' => :'vat',
    :'fiscal_code' => :'fiscal_code',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/invoicetronic_sdk/models/company.rb', line 249

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/invoicetronic_sdk/models/company.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
# File 'lib/invoicetronic_sdk/models/company.rb', line 64

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'version' => :'Integer',
    :'user_id' => :'Integer',
    :'vat' => :'String',
    :'fiscal_code' => :'String',
    :'name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



222
223
224
225
226
227
228
229
230
231
232
# File 'lib/invoicetronic_sdk/models/company.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      version == o.version &&
      user_id == o.user_id &&
      vat == o.vat &&
      fiscal_code == o.fiscal_code &&
      name == o.name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/invoicetronic_sdk/models/company.rb', line 236

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



242
243
244
# File 'lib/invoicetronic_sdk/models/company.rb', line 242

def hash
  [id, created, version, user_id, vat, fiscal_code, name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/invoicetronic_sdk/models/company.rb', line 135

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @vat.nil?
    invalid_properties.push('invalid value for "vat", vat cannot be nil.')
  end

  if @vat.to_s.length < 1
    invalid_properties.push('invalid value for "vat", the character length must be greater than or equal to 1.')
  end

  if @fiscal_code.nil?
    invalid_properties.push('invalid value for "fiscal_code", fiscal_code cannot be nil.')
  end

  if @fiscal_code.to_s.length < 1
    invalid_properties.push('invalid value for "fiscal_code", the character length must be greater than or equal to 1.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/invoicetronic_sdk/models/company.rb', line 271

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
173
174
175
176
# File 'lib/invoicetronic_sdk/models/company.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @vat.nil?
  return false if @vat.to_s.length < 1
  return false if @fiscal_code.nil?
  return false if @fiscal_code.to_s.length < 1
  return false if @name.nil?
  return false if @name.to_s.length < 1
  true
end