Class: Invoicetronic_Sdk::CompanyApi

Inherits:
Object
  • Object
show all
Defined in:
lib/invoicetronic_sdk/api/company_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CompanyApi

Returns a new instance of CompanyApi.



19
20
21
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#company_get(opts = {}) ⇒ Array<Company>

List companies Retrieve a paginated list of companies. Results can be filtered by free-text search (‘q`) across name, VAT number, and fiscal code. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number. (default to 1)

  • :page_size (Integer)

    Items per page. Cannot be greater than 200. (default to 100)

  • :sort (String)

    Sort by field. Prefix with &#39;-&#39; for descending order.

  • :q (String)

    Full-text search across committente, prestatore, identifier, and file name.

Returns:



30
31
32
33
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 30

def company_get(opts = {})
  data, _status_code, _headers = company_get_with_http_info(opts)
  data
end

#company_get_with_http_info(opts = {}) ⇒ Array<(Array<Company>, Integer, Hash)>

List companies Retrieve a paginated list of companies. Results can be filtered by free-text search (&#x60;q&#x60;) across name, VAT number, and fiscal code. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number. (default to 1)

  • :page_size (Integer)

    Items per page. Cannot be greater than 200. (default to 100)

  • :sort (String)

    Sort by field. Prefix with &#39;-&#39; for descending order.

  • :q (String)

    Full-text search across committente, prestatore, identifier, and file name.

Returns:

  • (Array<(Array<Company>, Integer, Hash)>)

    Array<Company> data, response status code and response headers



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 43

def company_get_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CompanyApi.company_get ...'
  end
  # resource path
  local_var_path = '/company'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<Company>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Basic']

  new_options = opts.merge(
    :operation => :"CompanyApi.company_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CompanyApi#company_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#company_id_delete(id, opts = {}) ⇒ Company

Delete a company Delete a company by its internal id. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received. Warning: Deleting a company will permanently remove all associated data, including sent invoices, received invoices, invoice updates from SDI, logs, and webhooks. If the company has any linked invoices, you must explicitly confirm deletion by adding ‘?force=true` to the request. Without this parameter, the API will return `409 Conflict` with details about the linked data.

Parameters:

  • id (Integer)

    Item id

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :force (Boolean)

    Force delete including all related data. (default to false)

Returns:



97
98
99
100
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 97

def company_id_delete(id, opts = {})
  data, _status_code, _headers = company_id_delete_with_http_info(id, opts)
  data
end

#company_id_delete_with_http_info(id, opts = {}) ⇒ Array<(Company, Integer, Hash)>

Delete a company Delete a company by its internal id. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received. Warning: Deleting a company will permanently remove all associated data, including sent invoices, received invoices, invoice updates from SDI, logs, and webhooks. If the company has any linked invoices, you must explicitly confirm deletion by adding &#x60;?force&#x3D;true&#x60; to the request. Without this parameter, the API will return &#x60;409 Conflict&#x60; with details about the linked data.

Parameters:

  • id (Integer)

    Item id

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :force (Boolean)

    Force delete including all related data. (default to false)

Returns:

  • (Array<(Company, Integer, Hash)>)

    Company data, response status code and response headers



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 108

def company_id_delete_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CompanyApi.company_id_delete ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling CompanyApi.company_id_delete"
  end
  # resource path
  local_var_path = '/company/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'force'] = opts[:'force'] if !opts[:'force'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Company'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Basic']

  new_options = opts.merge(
    :operation => :"CompanyApi.company_id_delete",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CompanyApi#company_id_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#company_id_get(id, opts = {}) ⇒ Company

Get a company by id Retrieve a company by its internal id. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received.

Parameters:

  • id (Integer)

    Item id

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



162
163
164
165
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 162

def company_id_get(id, opts = {})
  data, _status_code, _headers = company_id_get_with_http_info(id, opts)
  data
end

#company_id_get_with_http_info(id, opts = {}) ⇒ Array<(Company, Integer, Hash)>

Get a company by id Retrieve a company by its internal id. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received.

Parameters:

  • id (Integer)

    Item id

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Company, Integer, Hash)>)

    Company data, response status code and response headers



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 172

def company_id_get_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CompanyApi.company_id_get ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling CompanyApi.company_id_get"
  end
  # resource path
  local_var_path = '/company/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Company'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Basic']

  new_options = opts.merge(
    :operation => :"CompanyApi.company_id_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CompanyApi#company_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#company_post(company, opts = {}) ⇒ Company

Add a company Add a new company. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received.

Parameters:

  • company (Company)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



225
226
227
228
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 225

def company_post(company, opts = {})
  data, _status_code, _headers = company_post_with_http_info(company, opts)
  data
end

#company_post_with_http_info(company, opts = {}) ⇒ Array<(Company, Integer, Hash)>

Add a company Add a new company. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received.

Parameters:

  • company (Company)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Company, Integer, Hash)>)

    Company data, response status code and response headers



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 235

def company_post_with_http_info(company, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CompanyApi.company_post ...'
  end
  # verify the required parameter 'company' is set
  if @api_client.config.client_side_validation && company.nil?
    fail ArgumentError, "Missing the required parameter 'company' when calling CompanyApi.company_post"
  end
  # resource path
  local_var_path = '/company'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(company)

  # return_type
  return_type = opts[:debug_return_type] || 'Company'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Basic']

  new_options = opts.merge(
    :operation => :"CompanyApi.company_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CompanyApi#company_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#company_put(company, opts = {}) ⇒ Company

Update a company Update an existing company. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received.

Parameters:

  • company (Company)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



293
294
295
296
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 293

def company_put(company, opts = {})
  data, _status_code, _headers = company_put_with_http_info(company, opts)
  data
end

#company_put_with_http_info(company, opts = {}) ⇒ Array<(Company, Integer, Hash)>

Update a company Update an existing company. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received.

Parameters:

  • company (Company)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Company, Integer, Hash)>)

    Company data, response status code and response headers



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 303

def company_put_with_http_info(company, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CompanyApi.company_put ...'
  end
  # verify the required parameter 'company' is set
  if @api_client.config.client_side_validation && company.nil?
    fail ArgumentError, "Missing the required parameter 'company' when calling CompanyApi.company_put"
  end
  # resource path
  local_var_path = '/company'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(company)

  # return_type
  return_type = opts[:debug_return_type] || 'Company'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Basic']

  new_options = opts.merge(
    :operation => :"CompanyApi.company_put",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CompanyApi#company_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#company_vat_get(vat, opts = {}) ⇒ Company

Get a company by vat number Retrieve a company by its VAT number. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received.

Parameters:

  • vat (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



361
362
363
364
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 361

def company_vat_get(vat, opts = {})
  data, _status_code, _headers = company_vat_get_with_http_info(vat, opts)
  data
end

#company_vat_get_with_http_info(vat, opts = {}) ⇒ Array<(Company, Integer, Hash)>

Get a company by vat number Retrieve a company by its VAT number. Companies are the entities that send and receive invoices. They are automatically created from invoice data when invoices are sent or received.

Parameters:

  • vat (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Company, Integer, Hash)>)

    Company data, response status code and response headers



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/invoicetronic_sdk/api/company_api.rb', line 371

def company_vat_get_with_http_info(vat, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CompanyApi.company_vat_get ...'
  end
  # verify the required parameter 'vat' is set
  if @api_client.config.client_side_validation && vat.nil?
    fail ArgumentError, "Missing the required parameter 'vat' when calling CompanyApi.company_vat_get"
  end
  # resource path
  local_var_path = '/company/{vat}'.sub('{' + 'vat' + '}', CGI.escape(vat.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Company'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Basic']

  new_options = opts.merge(
    :operation => :"CompanyApi.company_vat_get",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CompanyApi#company_vat_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end