Class: Invoicetronic_Sdk::Event

Inherits:
ApiModelBase show all
Defined in:
lib/invoicetronic_sdk/models/event.rb

Overview

An API request log entry.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Event

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/invoicetronic_sdk/models/event.rb', line 140

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Invoicetronic_Sdk::Event` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Invoicetronic_Sdk::Event`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'api_key_id')
    self.api_key_id = attributes[:'api_key_id']
  end

  if attributes.key?(:'company_id')
    self.company_id = attributes[:'company_id']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  else
    self.method = nil
  end

  if attributes.key?(:'endpoint')
    self.endpoint = attributes[:'endpoint']
  else
    self.endpoint = nil
  end

  if attributes.key?(:'api_version')
    self.api_version = attributes[:'api_version']
  end

  if attributes.key?(:'status_code')
    self.status_code = attributes[:'status_code']
  end

  if attributes.key?(:'date_time')
    self.date_time = attributes[:'date_time']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'resource_id')
    self.resource_id = attributes[:'resource_id']
  end

  if attributes.key?(:'user_agent')
    self.user_agent = attributes[:'user_agent']
  end

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  end

  if attributes.key?(:'query')
    self.query = attributes[:'query']
  end

  if attributes.key?(:'response_body')
    self.response_body = attributes[:'response_body']
  end
end

Instance Attribute Details

#api_key_idObject

Api key id.



32
33
34
# File 'lib/invoicetronic_sdk/models/event.rb', line 32

def api_key_id
  @api_key_id
end

#api_versionObject

Api version.



44
45
46
# File 'lib/invoicetronic_sdk/models/event.rb', line 44

def api_version
  @api_version
end

#company_idObject

Company id.



35
36
37
# File 'lib/invoicetronic_sdk/models/event.rb', line 35

def company_id
  @company_id
end

#createdObject

Creation date. It is set automatically.



23
24
25
# File 'lib/invoicetronic_sdk/models/event.rb', line 23

def created
  @created
end

#date_timeObject

Date and time of the request.



50
51
52
# File 'lib/invoicetronic_sdk/models/event.rb', line 50

def date_time
  @date_time
end

#endpointObject

API endpoint.



41
42
43
# File 'lib/invoicetronic_sdk/models/event.rb', line 41

def endpoint
  @endpoint
end

#errorObject

Response error.



53
54
55
# File 'lib/invoicetronic_sdk/models/event.rb', line 53

def error
  @error
end

#idObject

Unique identifier. For POST requests, leave it at ‘0` — the server will assign one automatically. For PUT requests, set it to the id of the record you want to update.



20
21
22
# File 'lib/invoicetronic_sdk/models/event.rb', line 20

def id
  @id
end

#methodObject

Request method.



38
39
40
# File 'lib/invoicetronic_sdk/models/event.rb', line 38

def method
  @method
end

#queryObject

Request query. Only used for internal logging, not sent to webhooks.



65
66
67
# File 'lib/invoicetronic_sdk/models/event.rb', line 65

def query
  @query
end

#resource_idObject

ID of the resource created or modified by this request.



56
57
58
# File 'lib/invoicetronic_sdk/models/event.rb', line 56

def resource_id
  @resource_id
end

#response_bodyObject

Response payload. It is guaranteed to be encrypted at rest.



68
69
70
# File 'lib/invoicetronic_sdk/models/event.rb', line 68

def response_body
  @response_body
end

#status_codeObject

Status code returned by the API.



47
48
49
# File 'lib/invoicetronic_sdk/models/event.rb', line 47

def status_code
  @status_code
end

#successObject

Whether the request was successful.



62
63
64
# File 'lib/invoicetronic_sdk/models/event.rb', line 62

def success
  @success
end

#user_agentObject

User-Agent header from the HTTP request.



59
60
61
# File 'lib/invoicetronic_sdk/models/event.rb', line 59

def user_agent
  @user_agent
end

#user_idObject

User id.



29
30
31
# File 'lib/invoicetronic_sdk/models/event.rb', line 29

def user_id
  @user_id
end

#versionObject

Row version, for optimistic concurrency. It is set automatically.



26
27
28
# File 'lib/invoicetronic_sdk/models/event.rb', line 26

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



94
95
96
# File 'lib/invoicetronic_sdk/models/event.rb', line 94

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



99
100
101
# File 'lib/invoicetronic_sdk/models/event.rb', line 99

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/invoicetronic_sdk/models/event.rb', line 71

def self.attribute_map
  {
    :'id' => :'id',
    :'created' => :'created',
    :'version' => :'version',
    :'user_id' => :'user_id',
    :'api_key_id' => :'api_key_id',
    :'company_id' => :'company_id',
    :'method' => :'method',
    :'endpoint' => :'endpoint',
    :'api_version' => :'api_version',
    :'status_code' => :'status_code',
    :'date_time' => :'date_time',
    :'error' => :'error',
    :'resource_id' => :'resource_id',
    :'user_agent' => :'user_agent',
    :'success' => :'success',
    :'query' => :'query',
    :'response_body' => :'response_body'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/invoicetronic_sdk/models/event.rb', line 344

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
131
132
133
134
135
136
# File 'lib/invoicetronic_sdk/models/event.rb', line 127

def self.openapi_nullable
  Set.new([
    :'company_id',
    :'error',
    :'resource_id',
    :'user_agent',
    :'query',
    :'response_body'
  ])
end

.openapi_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/invoicetronic_sdk/models/event.rb', line 104

def self.openapi_types
  {
    :'id' => :'Integer',
    :'created' => :'Time',
    :'version' => :'Integer',
    :'user_id' => :'Integer',
    :'api_key_id' => :'Integer',
    :'company_id' => :'Integer',
    :'method' => :'String',
    :'endpoint' => :'String',
    :'api_version' => :'Integer',
    :'status_code' => :'Integer',
    :'date_time' => :'Time',
    :'error' => :'String',
    :'resource_id' => :'Integer',
    :'user_agent' => :'String',
    :'success' => :'Boolean',
    :'query' => :'String',
    :'response_body' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/invoicetronic_sdk/models/event.rb', line 307

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created == o.created &&
      version == o.version &&
      user_id == o.user_id &&
      api_key_id == o.api_key_id &&
      company_id == o.company_id &&
      method == o.method &&
      endpoint == o.endpoint &&
      api_version == o.api_version &&
      status_code == o.status_code &&
      date_time == o.date_time &&
      error == o.error &&
      resource_id == o.resource_id &&
      user_agent == o.user_agent &&
      success == o.success &&
      query == o.query &&
      response_body == o.response_body
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


331
332
333
# File 'lib/invoicetronic_sdk/models/event.rb', line 331

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



337
338
339
# File 'lib/invoicetronic_sdk/models/event.rb', line 337

def hash
  [id, created, version, user_id, api_key_id, company_id, method, endpoint, api_version, status_code, date_time, error, resource_id, user_agent, success, query, response_body].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/invoicetronic_sdk/models/event.rb', line 229

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @method.nil?
    invalid_properties.push('invalid value for "method", method cannot be nil.')
  end

  if @method.to_s.length < 1
    invalid_properties.push('invalid value for "method", the character length must be greater than or equal to 1.')
  end

  if @endpoint.nil?
    invalid_properties.push('invalid value for "endpoint", endpoint cannot be nil.')
  end

  if @endpoint.to_s.length < 1
    invalid_properties.push('invalid value for "endpoint", the character length must be greater than or equal to 1.')
  end

  if !@user_agent.nil? && @user_agent.to_s.length > 512
    invalid_properties.push('invalid value for "user_agent", the character length must be smaller than or equal to 512.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/invoicetronic_sdk/models/event.rb', line 366

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



257
258
259
260
261
262
263
264
265
# File 'lib/invoicetronic_sdk/models/event.rb', line 257

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @method.nil?
  return false if @method.to_s.length < 1
  return false if @endpoint.nil?
  return false if @endpoint.to_s.length < 1
  return false if !@user_agent.nil? && @user_agent.to_s.length > 512
  true
end