Class: Invoicetronic_Sdk::HealthApi
- Inherits:
-
Object
- Object
- Invoicetronic_Sdk::HealthApi
- Defined in:
- lib/invoicetronic_sdk/api/health_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#health_get(opts = {}) ⇒ nil
Health check Returns the health status of the API and its dependencies.
-
#health_get_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Health check Returns the health status of the API and its dependencies.
-
#initialize(api_client = ApiClient.default) ⇒ HealthApi
constructor
A new instance of HealthApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/invoicetronic_sdk/api/health_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#health_get(opts = {}) ⇒ nil
Health check Returns the health status of the API and its dependencies. No authentication required. Rate limited to 12 requests per minute.
26 27 28 29 |
# File 'lib/invoicetronic_sdk/api/health_api.rb', line 26 def health_get(opts = {}) health_get_with_http_info(opts) nil end |
#health_get_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Health check Returns the health status of the API and its dependencies. No authentication required. Rate limited to 12 requests per minute.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/invoicetronic_sdk/api/health_api.rb', line 35 def health_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HealthApi.health_get ...' end # resource path local_var_path = '/health' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['Basic'] = opts.merge( :operation => :"HealthApi.health_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HealthApi#health_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |