Class: Invoicetronic_Sdk::SendReduced
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Invoicetronic_Sdk::SendReduced
- Defined in:
- lib/invoicetronic_sdk/models/send_reduced.rb
Overview
Reduced Send data for Update responses, containing only the essential fields.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#date_sent ⇒ Object
When the invoice was sent to SDI.
-
#documents ⇒ Object
The invoices included in the payload.
-
#identifier ⇒ Object
SDI identifier.
-
#latest_state ⇒ Object
Current SDI state of the invoice.
-
#meta_data ⇒ Object
Optional metadata, as json.
-
#prestatore ⇒ Object
VAT number of the Cedente/Prestatore (vendor).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendReduced
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendReduced
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Invoicetronic_Sdk::SendReduced` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Invoicetronic_Sdk::SendReduced`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] end if attributes.key?(:'prestatore') self.prestatore = attributes[:'prestatore'] end if attributes.key?(:'meta_data') if (value = attributes[:'meta_data']).is_a?(Hash) self. = value end end if attributes.key?(:'documents') if (value = attributes[:'documents']).is_a?(Array) self.documents = value end end if attributes.key?(:'date_sent') self.date_sent = attributes[:'date_sent'] end if attributes.key?(:'latest_state') self.latest_state = attributes[:'latest_state'] end end |
Instance Attribute Details
#date_sent ⇒ Object
When the invoice was sent to SDI.
32 33 34 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 32 def date_sent @date_sent end |
#documents ⇒ Object
The invoices included in the payload.
29 30 31 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 29 def documents @documents end |
#identifier ⇒ Object
SDI identifier.
20 21 22 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 20 def identifier @identifier end |
#latest_state ⇒ Object
Current SDI state of the invoice. Reflects the most recent update received from SDI.
35 36 37 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 35 def latest_state @latest_state end |
#meta_data ⇒ Object
Optional metadata, as json.
26 27 28 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 26 def @meta_data end |
#prestatore ⇒ Object
VAT number of the Cedente/Prestatore (vendor).
23 24 25 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 23 def prestatore @prestatore end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 60 def self.attribute_map { :'identifier' => :'identifier', :'prestatore' => :'prestatore', :'meta_data' => :'meta_data', :'documents' => :'documents', :'date_sent' => :'date_sent', :'latest_state' => :'latest_state' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 205 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 98 99 100 101 102 103 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 94 def self.openapi_nullable Set.new([ :'identifier', :'prestatore', :'meta_data', :'documents', :'date_sent', :'latest_state' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 82 def self.openapi_types { :'identifier' => :'String', :'prestatore' => :'String', :'meta_data' => :'Hash<String, String>', :'documents' => :'Array<DocumentData>', :'date_sent' => :'Time', :'latest_state' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 179 def ==(o) return true if self.equal?(o) self.class == o.class && identifier == o.identifier && prestatore == o.prestatore && == o. && documents == o.documents && date_sent == o.date_sent && latest_state == o.latest_state end |
#eql?(o) ⇒ Boolean
192 193 194 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 192 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
198 199 200 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 198 def hash [identifier, prestatore, , documents, date_sent, latest_state].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
160 161 162 163 164 165 |
# File 'lib/invoicetronic_sdk/models/send_reduced.rb', line 160 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' latest_state_validator = EnumAttributeValidator.new('String', ["Inviato", "Consegnato", "NonConsegnato", "Scartato", "AccettatoDalDestinatario", "RifiutatoDalDestinatario", "ImpossibilitaDiRecapito", "DecorrenzaTermini", "AttestazioneTrasmissioneFattura"]) return false unless latest_state_validator.valid?(@latest_state) true end |