Class: Invoicetronic_Sdk::Error
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Invoicetronic_Sdk::Error
- Defined in:
- lib/invoicetronic_sdk/models/error.rb
Overview
Validation error from the SDI.
Instance Attribute Summary collapse
-
#code ⇒ Object
Error code.
-
#description ⇒ Object
Error description.
-
#hint ⇒ Object
Hint on how to solve the issue.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Error
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Error
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Invoicetronic_Sdk::Error` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Invoicetronic_Sdk::Error`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'code') self.code = attributes[:'code'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'hint') self.hint = attributes[:'hint'] end end |
Instance Attribute Details
#code ⇒ Object
Error code.
20 21 22 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 20 def code @code end |
#description ⇒ Object
Error description.
23 24 25 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 23 def description @description end |
#hint ⇒ Object
Hint on how to solve the issue.
26 27 28 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 26 def hint @hint end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 29 def self.attribute_map { :'code' => :'code', :'description' => :'description', :'hint' => :'hint' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 134 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 61 62 63 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 57 def self.openapi_nullable Set.new([ :'code', :'description', :'hint' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 48 def self.openapi_types { :'code' => :'String', :'description' => :'String', :'hint' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 111 def ==(o) return true if self.equal?(o) self.class == o.class && code == o.code && description == o.description && hint == o.hint end |
#eql?(o) ⇒ Boolean
121 122 123 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 121 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
127 128 129 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 127 def hash [code, description, hint].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
96 97 98 99 100 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 96 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 156 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
104 105 106 107 |
# File 'lib/invoicetronic_sdk/models/error.rb', line 104 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |