Class: Invoicetronic_Sdk::StatusApi
- Inherits:
-
Object
- Object
- Invoicetronic_Sdk::StatusApi
- Defined in:
- lib/invoicetronic_sdk/api/status_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ StatusApi
constructor
A new instance of StatusApi.
-
#status_get(opts = {}) ⇒ Status
Account status Retrieve the number of operations (invoices + validations) and signatures left on your account.
-
#status_get_with_http_info(opts = {}) ⇒ Array<(Status, Integer, Hash)>
Account status Retrieve the number of operations (invoices + validations) and signatures left on your account.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/invoicetronic_sdk/api/status_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#status_get(opts = {}) ⇒ Status
Account status Retrieve the number of operations (invoices + validations) and signatures left on your account. When ‘signature_left` is 0, you will receive a `403 Forbidden` response when trying to sign an invoice. Likewise, if `operation_left` is 0, you will receive a `403 Forbidden` response when storing or validating an invoice. You can also check your account status from the [Dashboard](dashboard.invoicetronic.com), where you can purchase additional operations and/or signatures. **Please note** that these values are not enforced if you are on the [Sandbox](invoicetronic.com/en/docs/sandbox/).
26 27 28 29 |
# File 'lib/invoicetronic_sdk/api/status_api.rb', line 26 def status_get(opts = {}) data, _status_code, _headers = status_get_with_http_info(opts) data end |
#status_get_with_http_info(opts = {}) ⇒ Array<(Status, Integer, Hash)>
Account status Retrieve the number of operations (invoices + validations) and signatures left on your account. When `signature_left` is 0, you will receive a `403 Forbidden` response when trying to sign an invoice. Likewise, if `operation_left` is 0, you will receive a `403 Forbidden` response when storing or validating an invoice. You can also check your account status from the [Dashboard](dashboard.invoicetronic.com), where you can purchase additional operations and/or signatures. **Please note** that these values are not enforced if you are on the [Sandbox](invoicetronic.com/en/docs/sandbox/).
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/invoicetronic_sdk/api/status_api.rb', line 35 def status_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: StatusApi.status_get ...' end # resource path local_var_path = '/status' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Status' # auth_names auth_names = opts[:debug_auth_names] || ['Basic'] = opts.merge( :operation => :"StatusApi.status_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: StatusApi#status_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |